/* AIM_COMM_DEFS.H */

/*******************************************************************************
*
* Acquisition Interface Module (AIM) Communications Definitions
*
*	This module contains definitions for the commands used by networked
*	data acquisition modules to talk to host computers. Note that the
*	basic communications protocol definitions are in NCP_COMM_DEFS.
*
* NOTE: Nearly all of these definitions are tied to the AIM firmware, i.e.
*       they define the format of the data packets to/from the AIM. Thus
*       these definitions cannot be changed unless the AIM firmware is changed.
*
********************************************************************************
*
* Revision History
*
*	30-Dec-1993	MLR	Modified from Nuclear Data source
*
*******************************************************************************/

/*
* Host to Module Command Definitions
*/

/*
* The command codes are found in ncp_comm_packet.packet_code.
* Following each code definition is its argument structure, and, if required,
* the normal module response code and structure structure.
*/

#define NCP_K_HCMD_SETACQADDR	1		/* SET ACQUISITION ADDRESS */
struct ncp_hcmd_setacqaddr {
	unsigned short adc;			/* ADC number */
	unsigned long address;			/* Acquisition address */
	unsigned long limit;			/* Acquisition limit address */
};

#define NCP_K_HCMD_SETELAPSED	2		/* SET ELAPSED TIMES */
struct ncp_hcmd_setelapsed {
	unsigned short adc;
	unsigned long live;			/* Elapsed live time */
	unsigned long real;			/*         real      */
};

#define NCP_K_HCMD_SETMEMORY	3		/* SET MEMORY */
struct ncp_hcmd_setmemory {
	unsigned long address;			/* Destination address of data */
	unsigned long size;			/* Amount of data (bytes) */
						/* Start of data */
};

#define NCP_K_HCMD_SETMEMCMP	4		/* SET MEMORY COMPRESSED */
struct ncp_hcmd_setmemcmp {
	unsigned long address;			/* Destination address of data */
	unsigned long size;			/* Amount of data (bytes) */
						/* Start of data */
};

#define NCP_K_HCMD_SETPRESETS	5		/* SET PRESETS */
struct ncp_hcmd_setpresets {
	unsigned short adc;
	unsigned long live;			/* Preset live time */
	unsigned long real;			/*        real      */
	unsigned long totals;			/* Preset total counts */
	unsigned long start;			/* Preset totals start channel */
	unsigned long end;			/*               end channel */
	unsigned long limit;			/* Preset limit */
};

#define NCP_K_HCMD_SETACQSTATUS	6		/* SET ACQUISITION STATUS */
struct ncp_hcmd_setacqstate {
	unsigned short adc;
	char status;				/* New acquisition status (on/off) */
};

#define NCP_K_HCMD_ERASEMEM	7		/* ERASE MEMORY */
struct ncp_hcmd_erasemem {
	unsigned long address;			/* Start address of memory to be erased */
	unsigned long size;			/* Number of bytes to be erased */
};

#define NCP_K_HCMD_SETACQMODE	8		/* SET ACQUISITION MODE */
struct ncp_hcmd_setacqmode {
	unsigned short adc;
	char mode;				/* Acquisition mode; see NCP_C_AMODE_xxx */
};

#define NCP_K_HCMD_RETMEMORY	9		/* RETURN MEMORY */
struct ncp_hcmd_retmemory {
	unsigned long address;			/* Start address of memory to return */
	unsigned long size;			/* Number of bytes of memory to return */
};

#define NCP_K_HCMD_RETMEMCMP	10		/* RETURN MEMORY COMPRESSED */
struct ncp_hcmd_retmemcmp {
	unsigned long address;			/* Start address of memory to return */
	unsigned long size;			/* Number of bytes of memory to return */
};
#define NCP_K_MRESP_RETMEMCMP	227
struct ncp_mresp_retmemcmp {
	unsigned long channels;			/* Number of channels of encoded data following */
						/* Encoded data starts here */
};

#define NCP_K_HCMD_RETADCSTATUS	11		/* RETURN ADC STATUS */
struct ncp_hcmd_retadcstatus {
	unsigned short adc;
};
#define NCP_K_MRESP_ADCSTATUS	35
struct ncp_mresp_retadcstatus {
	char status;				/* ADC on/off status */
	unsigned long live;			/* Elapsed live time */
	unsigned long real;			/*         real      */
	unsigned long totals;			/*         total counts */
};

#define NCP_K_HCMD_SETHOSTMEM	13		/* SET HOST MEMORY */
struct ncp_hcmd_sethostmem {
	unsigned long address;			/* Destination address of host data */
	unsigned long size;			/* Amount of data (bytes) */
						/* Start of data */
};

#define NCP_K_HCMD_RETHOSTMEM	14		/* RETURN HOST MEMORY */
struct ncp_hcmd_rethostmem {
	unsigned long address;			/* Start address of host memory to return */
	unsigned long size;			/* Number of bytes of memory to return */
};

#define NCP_K_HCMD_SETOWNER	15		/* SET OWNER */
struct ncp_hcmd_setowner {
	unsigned char owner_id[6];		/* New owner ID */
	char owner_name[8];			/* New owner name */
};

#define NCP_K_HCMD_SETOWNEROVER	16		/* SET OWNER OVERRIDE */
struct ncp_hcmd_setownerover {
	unsigned char owner_id[6];		/* New owner ID */
	char owner_name[8];			/* New owner name */
};

#define NCP_K_HCMD_RESET	17		/* RESET MODULE */
#define NCP_K_HCMD_SETDISPLAY	18		/* SET DISPLAY CHARACTERISTICS */
#define NCP_K_HCMD_RETDISPLAY	19		/* RETURN DISPLAY */
#define NCP_K_HCMD_DIAGNOSE	20		/* DIAGNOSE */

#define NCP_K_HCMD_SENDICB	21		/* SEND TO ICB */
struct ncp_hcmd_sendicb {
	unsigned long registers;		/* Number of address/data pairs to write */
	struct {
	   unsigned char address;		/* ICB address where data will be sent */
	   unsigned char data;			/* data to write */
	} addresses[64];
};

#define NCP_K_HCMD_RECVICB	22		/* RECEIVE FROM ICB */
struct ncp_hcmd_recvicb {
	unsigned long registers;		/* Number of addresses to read */
	unsigned char address[64];		/* ICB addresses from which data is to be read */
};

#define NCP_K_HCMD_SETUPACQ	23		/* SETUP ACQUISITION */
struct ncp_hcmd_setupacq {
	unsigned short adc;
	unsigned long address;			/* Acquisition address */
	unsigned long alimit;			/* Acquisition limit address */
	unsigned long plive;			/* Preset live time */
	unsigned long preal;			/*        real      */
	unsigned long ptotals;			/* Preset total counts */
	unsigned long start;			/* Preset totals start channel */
	unsigned long end;			/*               end channel */
	unsigned long plimit;			/* Preset limit */
	unsigned long elive;			/* Elapsed live time */
	unsigned long ereal;			/*         real      */
	char mode;				/* Acquisition mode; see NCP_C_AMODE_xxx */
};

#define NCP_K_HCMD_RETACQSETUP	24		/* RETURN ACQUISITION SETUP INFO */
struct ncp_hcmd_retacqsetup {
	unsigned short adc;
};
#define NCP_K_MRESP_RETACQSETUP 203
struct ncp_mresp_retacqsetup {
	unsigned long address;			/* Acquisition address */
	unsigned long alimit;			/* Acquisition limit address */
	unsigned long plive;			/* Preset live time */
	unsigned long preal;			/*        real      */
	unsigned long ptotals;			/* Preset total counts */
	unsigned long start;			/* Preset totals start channel */
	unsigned long end;			/*               end channel */
	unsigned long plimit;			/* Preset limit */
	char mode;
};

#define NCP_K_HCMD_SETMODEVSAP	25		/* SET MODULE EVENT MESSAGE ADDRESSES*/
struct ncp_hcmd_setmodevsap {
	unsigned short	mevsource;		/* 0-255 are reserved for    */
						/* adc numbers. 255-65536    */
						/* are types NCP_K_MEVSRC_   */
	char	mev_dsap;			/* dest. service access point */
	char	mev_ssap;			/* sour. service access point */
	char	snap_id[5];			/* SNAP protocol ID */
};

#define NCP_K_HCMD_RETLISTMEM	26		/* RETURN LIST BUFFER */
struct ncp_hcmd_retlistmem {
	unsigned short adc;			/* adc number */
	unsigned long offset;			/* byte offset from start of buffer of transfer start */
	unsigned long size;			/* number of bytes to return */
	char buffer;				/* 0 for "1st" buffer, 1 for "2nd" */
};

#define NCP_K_HCMD_RELLISTMEM	27		/* RELEASE LIST BUFFER */
struct ncp_hcmd_rellistmem {
	unsigned short adc;			/* adc number */
	char buffer;				/* 0 for "1st" buffer, 1 for "2nd" */
};

#define NCP_K_HCMD_RETLISTSTAT	28		/* RETURN LIST ACQ STATUS */
struct ncp_hcmd_retliststat {
	unsigned short adc;			/* adc number */
};
#define NCP_K_MRESP_RETLISTSTAT 251
struct ncp_mresp_retliststat {
	char status;				/* acquire on/off state */
	char current_buffer;			/* current acquire buffer: 0 for "1st" buffer, 1 for "2nd" */
	char buffer_1_full;			/* 1st buffer status: 1 if full of data */
	unsigned long offset_1;			/* number of bytes of data in 1st buffer */
	char buffer_2_full;			/* 2nd buffer status: 1 if full of data */
	unsigned long offset_2;			/* number of bytes of data in 2nd buffer */
};

#define NCP_K_HCMD_RETMEMSEP	29		/* RETURN MEMORY SEPARATED */
struct ncp_hcmd_retmemsep {
	unsigned long address;			/* start address of first chunk of memory to return*/
	unsigned long size;			/* number of bytes per chunk */
	unsigned long offset;			/* byte offset between start of each chunk */
	unsigned long chunks;			/* number of chunks to return */
};						/* Note: total bytes returned will be */
						/*      size*chunks */

#define NCP_K_HCMD_RESETLIST	30		/* RESET LIST MODE */
struct ncp_hcmd_resetlist {
	unsigned short adc;			/* adc number */
};

/*
* Define format for host memory usage. This is used by hosts to store module
* setup information in the module itself. There are 256 bytes of memory total.
*/

	struct nam_hostmem_v0_struct {

	   char initialized;			/* True if host mem has been setup */
	   char version;			/* Version number of this structure */
	   long acqmem_usage_map[4];		/* Map of 8K blocks of acq memory */

	   struct {
		char used;			/* This input is used */
		char name[29];			/* Configuration name of the input */
		char owner[12];			/* Name of input's owner */
		long channels;			/* Number of channels assigned to input */
		unsigned short rows;		/*           rows */
		unsigned char groups;		/*           groups */
		long memory_start;		/* Start of acq mem for this input */
		unsigned char year;		/* Acquisition start year (base = 1900) */
		unsigned char month;		/*                   month */
		unsigned char day;		/*                   day */
		unsigned char hour;		/*                   hour */
		unsigned char minute;		/*                   minute */
		unsigned char seconds;		/*                   seconds */
	   } input[4];
	};

/*
* This structure defines the return argument from NMC_ACQU_GETACQSETUP; it
* characterizes the acquisition setup state of an AIM ADC.
*/

struct nmc_acqsetup_struct {

	char name[33];				/* configuration name */
	char owner[12];				/*               owner */
	int channels;
	int rows;
	int groups;
	int memory_start;			/* acq memory start address */
	int plive;				/* preset live time */
	int preal;				/*        real      */
	int ptotals;				/*        total counts */
	int start;				/* preset totals start region */
	int end;				/* preset totals end region */
	int plimit;				/* preset limit */
	int mode;				/* acquisition mode */
	int astime[2];				/* acqusition start date/time */
	int agroup;				/* acquire group */
	int status;				/* acquire status */
	int live;				/* elapsed live time */
	int real;				/*         real      */
	int totals;				/*         total counts */
};

/*
* Miscellaneous definitions
*/

/*
* Module acquisition modes
*/

#define NCP_C_AMODE_PHA		1		/* PHA */
#define NCP_C_AMODE_PHALFC	2		/* PHA/LFC */
#define NCP_C_AMODE_DLIST	3		/* Double buffered list */
